"""Type definitions - import when needed for type hints"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/types.ipynb.

# %% auto 0
__all__ = ['SpacingValue', 'FractionValue', 'SizeValue', 'OpacityValue', 'ZIndexValue', 'BaseColor', 'ColorShade', 'SpecialColor',
           'ColorValue']

# %% ../nbs/types.ipynb 3
from typing import Union, Literal

# %% ../nbs/types.ipynb 5
SpacingValue = Union[ # Extended spacing scale with new values from Tailwind v4
    Literal[0, 0.5, 1, 1.5, 2, 2.5, 3, 3.5, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 60, 62, 64, 68, 72, 76, 80, 84, 88, 92, 96],
    Literal["px", "auto", "full"]
]

# %% ../nbs/types.ipynb 6
FractionValue = Literal["1/2", "1/3", "2/3", "1/4", "2/4", "3/4", "1/5", "2/5", "3/5", "4/5", "1/6", "2/6", "3/6", "4/6", "5/6", "1/12", "2/12", "3/12", "4/12", "5/12", "6/12", "7/12", "8/12", "9/12", "10/12", "11/12"] # Fraction values

# %% ../nbs/types.ipynb 7
SizeValue = Union[SpacingValue, FractionValue, Literal["screen", "min", "max", "fit"]] # Common size values

# %% ../nbs/types.ipynb 8
OpacityValue = Literal[0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70, 75, 80, 85, 90, 95, 100] # Color opacity values

# %% ../nbs/types.ipynb 9
ZIndexValue = Union[Literal[0, 10, 20, 30, 40, 50], Literal["auto"]] # Z-index values

# %% ../nbs/types.ipynb 10
BaseColor = Literal[ # Base color names from Tailwind CSS color palette
    "slate", "gray", "zinc", "neutral", "stone",
    "red", "orange", "amber", "yellow", "lime", "green", 
    "emerald", "teal", "cyan", "sky", "blue", "indigo", 
    "violet", "purple", "fuchsia", "pink", "rose"
]

# %% ../nbs/types.ipynb 11
ColorShade = Literal[50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 950] # Standard color shade values

# %% ../nbs/types.ipynb 12
SpecialColor = Literal[ # Special color keywords
    "transparent", "current", "inherit", "white", "black"
]

# %% ../nbs/types.ipynb 13
ColorValue = Union[ # Complete color value type
    SpecialColor,
    str  # For base-shade combinations like "blue-500" or arbitrary values
]
